@@ -1,3 +1,3 @@
-from disc_python import *
+from disc_python.disc import *
 from disc_python.algoritmos import *
 from disc_python.corpus import *
\ No newline at end of file
