@@ -23,12 +23,12 @@ SIMPLES = {
     "sketches_simple":        "sketches"
     }
 
-__all__ = ['disc']
+__all__ = ['disc','get_disc']
 
 def disc(G, algo='sketches_simple', verbose = False, all_terms = False, *args, **kwargs):
     """Compute the DIS-C graph. This function can compute the DIS-C distance between pairs
     of concepts.
-    
+
     Parameters
     -----------
     G : NetworkX graph
@@ -108,7 +108,7 @@ def disc(G, algo='sketches_simple', verbose = False, all_terms = False, *args, *
             total_weight += w_ab + w_ba
         if verbose:
             print(" Computing thresholds ...")
-        curEPS = _compute(disc_graph, algo, all_terms=all_terms, **kwargs)
+        curEPS = _compute(disc_graph, G, algo, all_terms=all_terms, **kwargs)
         eps = (oldEPS - curEPS)**2
         oldEPS = curEPS
         if verbose:
@@ -164,7 +164,7 @@ def get_disc(disc, term_a, term_b):
 
 
 
-def _compute(disc, algo, all_terms, **kwargs):
+def _compute(disc, graph, algo, all_terms, **kwargs):
     """Redirect the computing of the DIS-C distnace.
 
     Params.
@@ -172,6 +172,9 @@ def _compute(disc, algo, all_terms, **kwargs):
     disc : NetworkX graph
         The DIS-C graph.
 
+    graph: NetworkX graph
+        The conceptual graph.
+
     algo : str
         The algorithm that will be executed to compute the DIS-C distance.
 
@@ -180,9 +183,9 @@ def _compute(disc, algo, all_terms, **kwargs):
     The average of the generality reached in the actual iteration.
     """
     if algo in STANDAR:
-         ret_val = _standard(disc, algo, all_terms=all_terms,  **kwargs)
+         ret_val = _standard(disc, graph, algo, all_terms=all_terms,  **kwargs)
     elif algo in SIMPLES:
-        ret_val = _simples(disc, algo, all_terms=all_terms, **kwargs)
+        ret_val = _simples(disc, graph, algo, all_terms=all_terms, **kwargs)
     else:
         raise ValueError("Algorithm in params does not exist. Please use: dijkstra, pruned_dijkstra,\
         sketche, pruned_dijkstra_simple or sketches_simple")
@@ -193,7 +196,7 @@ def _generality(fromm, to):
     """Return the generality of one node to the others."""
     return fromm / to
 
-def _standard(graph_disc, algo, all_terms = False, **kwargs):
+def _standard(graph_disc, graph, algo, all_terms = False, **kwargs):
     """Execute the standart algorithms to the DIS-C distance computing. This algorithms, to computing the
     DIS-C distance, resolve the APSP problem. That´s means, there are to steps to get the DIS-C distance.
     The first step compute the cover or index of the graph; this can be reached by using the PLL method
@@ -209,6 +212,9 @@ def _standard(graph_disc, algo, all_terms = False, **kwargs):
     graph_disc : NetworkX graph
         The DIS-C graph.
 
+    graph: NetworkX graph
+        The conceptual graph.
+
     algo : str
         The standart algorithm to be used in the distance computation.
 
@@ -228,8 +234,9 @@ def _standard(graph_disc, algo, all_terms = False, **kwargs):
     distances['in'] = dict()
     # compute the cover/index of the graph.
     apsp = getattr(algos, STANDAR[algo])(graph_disc, memory_save=True, **kwargs)
-    for _, pairs in kwargs['concepts'].items():
-        list_pairs.extend(pairs.values())
+    if not all_terms:
+        for _, pairs in kwargs['concepts'].items():
+            list_pairs.extend(pairs.values())
     for fromm, length in apsp:
         distances['out'][fromm] = 0
         if not all_terms:
@@ -248,13 +255,13 @@ def _standard(graph_disc, algo, all_terms = False, **kwargs):
                 distances['in'][k] = v
     for n in graph_disc:
         fromm, to = distances['out'][n], distances['in'][n]
-        v_a = graph_disc.nodes[n]['v_a']
+        v_a = graph.nodes[n]['v_a']
         ret_val += (v_a - _generality(fromm, to)) ** 2
-        graph_disc.nodes[n]['v_a'] = _generality(fromm, to)
+        graph.nodes[n]['v_a'] = _generality(fromm, to)
     return ret_val
 
 
-def _simples(graph_disc, algo, all_terms = False, **kwargs):
+def _simples(graph_disc, graph, algo, all_terms = False, **kwargs):
     """ Execute the simples algorithms to the DIS-C distance computing. This algorithms just compute
     the cover/index of the graph by using the techniques: PLL method (using Pruned dijkstra algorithm)
     or by Oracles Distance (using Skeching algorithm).
@@ -268,6 +275,9 @@ def _simples(graph_disc, algo, all_terms = False, **kwargs):
     graph_disc : NetworkX graph
         The DIS-C graph.
 
+    graph: NetworkX graph
+        The conceptual graph.
+
     algo : str
         The simple algorithm to be used in the distance computation.
 
@@ -314,12 +324,14 @@ def _simples(graph_disc, algo, all_terms = False, **kwargs):
             to += v
         for k,v in dict(labeling_landmark['out'][n]).items():
             fromm += v
-        v_a = graph_disc.nodes[n]['v_a']
+        v_a = graph.nodes[n]['v_a']
         ret_val += (v_a - _generality(fromm, to)) ** 2
-        graph_disc.nodes[n]['v_a'] = _generality(fromm, to)
+        graph.nodes[n]['v_a'] = _generality(fromm, to)
     return ret_val
 
 
+
+# NOT IMPLEMENTED
 def _floyd_warshall(graph_disc, graph, bound = None, **kwargs):
     from disc_python.algoritmos import all_pairs_floyd_warshall
 
